<?php
include('connexion.php');
session_start();

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
  
    if (!isset($_SESSION['logged_in']) || $_SESSION['logged_in'] !== true) {
       
        header('Location: login.php');
        exit;
    }

   
    $contenu_message = $_POST['contenu_message'];
    $id_utilisateur = $_SESSION['id_utilisateur'];

    $query_insert_message = "INSERT INTO messages (id_utilisateur, contenu_message, date_post) VALUES (:id_utilisateur, :contenu_message, NOW())";
    $stmt_insert_message = $db->prepare($query_insert_message);
    $stmt_insert_message->bindParam(':id_utilisateur', $id_utilisateur);
    $stmt_insert_message->bindParam(':contenu_message', $contenu_message);

    if ($stmt_insert_message->execute()) {

        header('Location: index.php');
        exit;
    } else {
        echo "Erreur lors de l'insertion du message.";
        exit;
    }
}

$query = "SELECT messages.contenu_message, messages.date_post, utilisateurs.nom_utilisateur
          FROM messages
          INNER JOIN utilisateurs ON messages.id_utilisateur = utilisateurs.id_utilisateur
          ORDER BY messages.date_post DESC
          LIMIT 10";

$stmt = $db->prepare($query);
$stmt->execute();
$messages = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>
<!DOCTYPE html>
<html>
<head>
    <title>Mini Chat</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 0;
            background-color: #f2f2f2;
        }

        h1 {
            text-align: center;
            color: #333;
        }

        .messages {
            max-width: 800px;
            margin: 20px auto;
            padding: 10px;
            background-color: #fff;
            border-radius: 5px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        .message {
            margin-bottom: 15px;
            padding: 10px;
            background-color: #f9f9f9;
            border-radius: 5px;
        }

        textarea {
            width: calc(100% - 22px);
            margin-bottom: 10px;
            padding: 5px;
            border: 1px solid #ccc;
            border-radius: 3px;
            resize: vertical;
        }

        input[type="submit"] {
            padding: 8px 15px;
            background-color: #4CAF50;
            color: white;
            border: none;
            border-radius: 3px;
            cursor: pointer;
        }

        input[type="submit"]:hover {
            background-color: #45a049;
        }

        a {
            text-decoration: none;
            color: #333;
            margin-right: 10px;
        }

        a:hover {
            text-decoration: underline;
        }

        .form-container {
            max-width: 400px;
            margin: 20px auto;
            padding: 20px;
            background-color: #fff;
            border-radius: 5px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        .error-message {
            color: red;
            margin-bottom: 10px;
        }
    </style>
</head>
<body>
    <!-- Affichage des 10 derniers messages -->
    <h1>Discussion</h1>
    <div class="messages">
        <?php foreach ($messages as $message) : ?>
            <div class="message">
                <p>
                    <strong><?= htmlspecialchars($message['nom_utilisateur']) ?></strong> - <?= $message['date_post'] ?><br>
                    <?= nl2br(htmlspecialchars($message['contenu_message'])) ?>
                </p>
            </div>
        <?php endforeach; ?>
    </div>
    
    <?php if (isset($_SESSION['logged_in']) && $_SESSION['logged_in'] === true) : ?>
        <form action="index.php" method="post">
            <textarea name="contenu_message" placeholder="Votre message" required></textarea>
            <input type="submit" value="Poster">
        </form>
        <a href="deconnexion.php">Se déconnecter</a>
    <?php else : ?>
        <a href="login.php">Se connecter</a> |
        <a href="inscription.php">S'inscrire</a>
    <?php endif; ?>
</body>
</html>
